class MasterAIAgent:
    """
    A simple Master Agent that responds to questions using a provided LLM model.
    """

    def __init__(self, name="Master Agent", llm=None):
        """
        Initialize the Master Agent.

        Args:
            name (str): The name of the agent.
            llm (object, optional): An optional LLM model object to generate responses.
        """
        self.name = name
        self.llm = llm  # Optional LLM model

    def answer_question(self, question):
        """
        Generates a response to a given question using the LLM model if provided.

        Args:
            question (str): The question to be answered.

        Returns:
            str: A response generated by the LLM or a simple response if no LLM is provided.
        """
        if self.llm:
            try:
                response = self.llm.invoke(question)
                return f"{self.name} (via LLM): {response}"
            except Exception as e:
                return f"{self.name} encountered an error with the LLM: {e}"

        # Fallback response if no LLM is provided
        response = f"{self.name} says: I have received your question - '{question}'. How can I assist further?"
        return response
